#!/usr/bin/env python3
"""Tools to help build an image"""

import logging
import os
import shutil
import sys
from typing import List, Optional

from .docker_build_copy import _PYTHON_PACKAGES_DIR
from .list_modules import MODULES_LIST_FILE
from .parsing import apply, basic_parser

_logger = logging.getLogger(__name__)

__version__ = "2.1.0"
__date__ = "2020-06-30"
__updated__ = "2023-02-27"


def __parser():
    program_version_message = f"%(prog)s {__version__} ({__updated__})"
    program_short_description = __doc__.split(".", maxsplit=1)[0]
    program_license = f"""{program_short_description}

      Created by Vincent Hatakeyama on {__date__}.
      Copyright 2020, 2021, 2023 XCG Consulting. All rights reserved.

      Licensed under the MIT License

      Distributed on an "AS IS" basis without warranties
      or conditions of any kind, either express or implied.

    USAGE
    """
    parser = basic_parser(program_license, program_version_message)
    return parser


def main(argv: Optional[List[str]] = None) -> int:
    """Clean up after a build, callable version that parses arguments"""
    parser = __parser()
    nmspc = parser.parse_args(argv)
    apply(nmspc)
    # TODO check odoo_scripts before deleting anything
    clean()
    return 0


def clean():
    """Clean up after a build"""
    if os.path.exists(MODULES_LIST_FILE):
        os.remove(MODULES_LIST_FILE)
    for directory in ("odoo_modules", "odoo_setup", _PYTHON_PACKAGES_DIR):
        if os.path.exists(directory):
            shutil.rmtree(directory)


if __name__ == "__main__":
    sys.exit(main())
