"""Py3o methods"""

import atexit
import logging

from python_on_whales import docker

from .docker_client import capture_docker_exit_code

_logger = logging.getLogger(__name__)


# TODO move to docker_client directly
def find_container(name):
    """Return container object from its name"""
    for container in docker.container.list(filters={"name": name}):
        return container
    return None


def remove_and_stop(docker_client, name):
    # TODO handle the case when the container has been created, not running
    tostop = find_container(name)
    docker_client.stop(tostop.get("Id"))
    docker_client.remove_container(tostop.get("Id"))


def start_py3o(host_fusion_port=8765, stop_at_exit=True):
    """start a py3o container"""
    fusion_repository = "xcgd/py3o"
    fusion_version = "1.0.0"
    fusion_name = "py3o_fusion"
    fusion_image = "{}:{}".format(fusion_repository, fusion_version)
    with capture_docker_exit_code() as exit_code:
        _logger.debug("Pulling %s", fusion_repository)
        docker.images.pull(f"{fusion_repository}:{fusion_version}")
    if exit_code:
        _logger.warning("Error when pulling")
    if docker.containers.list(filter={"name": fusion_name}):
        _logger.debug("%s Container already running", fusion_name)
        remove_and_stop(docker, fusion_name)
    # TODO handle --host-network option
    port_bindings = {8765: host_fusion_port}
    _logger.debug("Starting %s container", fusion_name)
    fusion = docker.containers.create(
        image=fusion_image, ports=port_bindings, name=fusion_name
    )
    _logger.debug("Starting %s container", fusion_name)
    fusion.start()

    def stop_py3o():
        # TODO test if still exists (no error if already stopped)
        _logger.info("Stopping fusion container")
        fusion.stop()
        fusion.wait()
        _logger.info("Removing fusion container")
        fusion.remove()

    if stop_at_exit:
        atexit.register(stop_py3o)
    return fusion_name, stop_py3o
